@@ -1,5 +1,5 @@
 import openpyxl
-from copy import copy
+import copy
 from openpyxl.styles import PatternFill, Border, Alignment, Font
 """
 Documentation
@@ -90,10 +90,10 @@ class Style:
         self.__row = row
         self.__column = column
         self.__data_type = data_type
-        self.__font = copy(font)
-        self.__alignment = copy(alignment)
-        self.__fill = copy(fill)
-        self.__border = copy(border)
+        self.__font = copy.copy(font)
+        self.__alignment = copy.copy(alignment)
+        self.__fill = copy.copy(fill)
+        self.__border = copy.copy(border)
 
     @property
     def name(self):
@@ -493,7 +493,7 @@ class Model:
         """
         Documentation
         """
-        self.__data = copy(data)
+        self.__data = copy.deepcopy(data)
         self.restyle()
         for variable in self.variables:
             if variable.name in self.data:
@@ -529,11 +529,11 @@ class Model:
             else:
                 worksheet.cell(variable.row, variable.column, variable.value)
         for style in self.styles:
-            #worksheet[style.name].data_type = copy(style.data_type)
-            worksheet[style.name].font = copy(style.font)
-            worksheet[style.name].fill = copy(style.fill)
-            worksheet[style.name].border = copy(style.border)
-            worksheet[style.name].alignment = copy(style.alignment)
+            #worksheet[style.name].data_type = copy.copy(style.data_type)
+            worksheet[style.name].font = copy.copy(style.font)
+            worksheet[style.name].fill = copy.copy(style.fill)
+            worksheet[style.name].border = copy.copy(style.border)
+            worksheet[style.name].alignment = copy.copy(style.alignment)
         for merge in self.mergedcells:
             worksheet.merge_cells(merge)
 
